@@ -8,4 +8,4 @@ def unescape(value):
 def parse_tsv(line):
     if line and line[-1] == b'\n':
         line = line[:-1]
-    return [unescape(x) if x != b'\N' else None for x in line.split(b'\t')]
+    return [unescape(x) if x != b'\\N' else None for x in line.split(b'\t')]
